import sys
import os
from copy import *
from types import *
from random import *
import Genome
import History

if len(sys.argv) != 4:
  print "Usage: python oe.py [strom] [genomy v listoch] [historia]"
  sys.exit(1)

tree = sys.argv[1]
leaves = sys.argv[2]
hist = sys.argv[3]

History.init (tree)
h = History.History(leaves)
h.read(hist)
h.fill_in_oe(0)
h.opt_neigh()
h.fill_in_oe(1)
h.opt_neigh()
print h.score()
print h



import sys

fn = 'gg'
f = open (fn, 'r')
name, gen = [], []
for line in f:
  n,g = line.split(' ', 1)
  name.append(n)
  gen.append(g[:-3])
f.close()
n = len(name)
for i in xrange(0,n-2):
  for j in xrange(i+1,n-1):
    for k in xrange(j+1,n):
      f = open ('med/'+str(i)+'-'+str(j)+'-'+str(k)+'.txt', 'w')
      print >> f, '>'+name[i]
      print >> f, 'C:', gen[i]
      print >> f, '>'+name[j]
      print >> f, 'C:', gen[j]
      print >> f, '>'+name[k]
      print >> f, 'C:', gen[k]
      f.close()




import sys
import os
from copy import *
from types import *
from random import *
import Genome
import History

if len(sys.argv) != 4:
  print "Usage: python tab.py [strom] [genomy v listoch] [historia]"
  sys.exit(1)

tree = sys.argv[1]
leaves = sys.argv[2]
hist = sys.argv[3]

History.init (tree)
h = History.History(leaves)
h.read(hist)

T = h.dist_tab()
for i in xrange(0, History.n):
  print History.name[i],
  for j in xrange(0, History.n):
    if i==j: print " 0",
    elif i>j: print "%2d" % T[i][j],
    else: print "%2d" % T[j][i],
  print
    

